#ifndef CT_SYSTEM_H
#define CT_SYSTEM_H

// commonly-included system headers
#include <cmath>
#include <fstream>
#include <iostream>
#include <sstream>
#include <cstdlib>
#include <vector>
#include <map>
#include <set>
#include <string>
#include <algorithm>
#include <memory>
#include <functional>
#include <any>

#include <boost/algorithm/string.hpp>

#endif
